Naming conventions
------------------

To facilitate learning and extending ``otupy``, all base and complex
structures are named as reported in the specifications. The following
conventional rules have been adopted to address the presence of illegal
characters and reserved keywords in Python: 

- a hyphen (‘-’) within a name is discarded (e.g., ‘IPv4-Addr’ is named ``IPv4Addr``); 
- names that are Python keywords are trailed with an underscore (e.g., ‘from’ becomes ``from_``).

